package com.jz.dmp.cmdexectool.scheduler.common.task.sync;

import com.alibaba.fastjson.JSONObject;
import com.jz.dmp.cmdexectool.common.constant.CommConstant;
import com.jz.dmp.cmdexectool.common.constant.DatasouceTypeConstant;
import com.jz.dmp.cmdexectool.common.utils.FreeMarkerUtils;
import com.jz.dmp.cmdexectool.controller.bean.DmpProjectConfigInfoDto;
import com.jz.dmp.cmdexectool.entity.DmpSyncingDatasource;
import com.jz.dmp.cmdexectool.mapper.DmpSyncingDatasourceDao;
import com.jz.dmp.cmdexectool.scheduler.common.process.ResourceInfo;
import com.jz.dmp.cmdexectool.scheduler.common.task.AbstractParameters;
import org.springframework.web.servlet.view.freemarker.FreeMarkerConfigurer;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @ClassName: SyncParameters
 * @Description: sync parameters
 * @Author : Bellamy
 * @Date 2021/2/25
 * @Version 1.0
 */
public class SyncParameters extends AbstractParameters {

    /**
     * shell script
     */
    private String script;

    private String taskAppId;

    /**
     * 数据源相关配置
     */
    private String source;

    /**
     * 目标相关配置
     */
    private String sink;

    /**
     * 环境相关配置
     */
    private String env;

    /**
     * ETL相关配置
     */
    private String transform;

    /**
     * waterdropScript脚本
     */
    private String waterdropScript;

    /**
     * resource list
     */
    private List<ResourceInfo> resourceList;

    public SyncParameters(String script, DmpProjectConfigInfoDto projectConfigInfoDto, DmpSyncingDatasourceDao dmpSyncingDatasourceDao, FreeMarkerConfigurer freeMarkerConfig) {
        source = "";
        env = "";
        sink = "";
        transform = "";

        this.script = script;

        JSONObject scriptObj = JSONObject.parseObject(script);
        Map<String, Object> scriptJson = (Map<String, Object>) scriptObj.get("params");
        Map<String, Object> scripts = (Map<String, Object>) scriptJson.get("scripts");
        Map<String, Object> source = (Map<String, Object>) scripts.get("reader");
        //evn
        Map<String, String> envModel = new HashMap<String, String>();
        envModel.put("sparkappname", "Waterdrop");
        env = FreeMarkerUtils.freemakerJson(CommConstant.WATERDROP_FTL_ENV, envModel, freeMarkerConfig);
        //Jdbc(MySQL、Oracle、SqlServer、PostgreSQL、Informix、DB2)
        //source
        Integer sourceId = Integer.valueOf((String) source.get("sourceDbId"));
        DmpSyncingDatasource dmpSyncingDatasource = dmpSyncingDatasourceDao.queryById(sourceId);
        Integer datasouceType = dmpSyncingDatasource.getDatasourceType();
        switch (datasouceType) {
            case DatasouceTypeConstant.MySQL:


                break;
            case DatasouceTypeConstant.SQLServer:

            default:
                break;
        }
    }

    @Override
    public boolean checkParameters() {
        return waterdropScript != null && !waterdropScript.isEmpty();
    }

    /**
     * get project resource files list
     *
     * @return resource files list
     */
    @Override
    public List<ResourceInfo> getResourceFilesList() {
        return resourceList;
    }

    public String getScript() {
        return script;
    }

    public void setScript(String script) {
        this.script = script;
    }

    public String getTaskAppId() {
        return taskAppId;
    }

    public void setTaskAppId(String taskAppId) {
        this.taskAppId = taskAppId;
    }

    public String getSource() {
        return source;
    }

    public void setSource(String source) {
        this.source = source;
    }

    public String getSink() {
        return sink;
    }

    public void setSink(String sink) {
        this.sink = sink;
    }

    public String getEnv() {
        return env;
    }

    public void setEnv(String env) {
        this.env = env;
    }

    public String getTransform() {
        return transform;
    }

    public void setTransform(String transform) {
        this.transform = transform;
    }

    public String getWaterdropScript() {
        return waterdropScript;
    }

    public void setWaterdropScript(String waterdropScript) {
        this.waterdropScript = waterdropScript;
    }

    public List<ResourceInfo> getResourceList() {
        return resourceList;
    }

    public void setResourceList(List<ResourceInfo> resourceList) {
        this.resourceList = resourceList;
    }
}
